"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.utils = exports.units = exports.unit = exports.theme = exports.styled = exports.media = exports.map = exports.keyframes = exports.input = exports.icon = exports.globalCss = exports.getCssText = exports.font = exports.css = exports.createTheme = exports.container = exports.config = exports.animation = void 0;
var _react = require("@stitches/react");
var _fontSizes = require("./foundations/fontSizes");
var _fontWeights = require("./foundations/fontWeights");
var _lineHeight = require("./foundations/lineHeight");
var _breakpoints = require("./foundations/breakpoints");
var _space = require("./foundations/space");
var _input = require("./foundations/input");
var _colors = require("./foundations/colors");
var _utils;
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
var animation = {
  shimmer: {
    "0%": {
      backgroundColor: "#e6e9f0"
    },
    "50%": {
      backgroundColor: "#EEF0F4"
    },
    "100%": {
      backgroundColor: "#e6e9f0"
    }
  },
  spinner: {
    from: {
      transform: "rotate(0deg)"
    },
    to: {
      transform: "rotate(360deg)"
    }
  }
};
exports.animation = animation;
var icon = {
  defaultColor: "#9B9B9B",
  size: {
    micro: 8,
    smaller: 12,
    small: 16,
    "default": 20,
    large: 24,
    huge: 36
  }
};
exports.icon = icon;
var map = [{
  featureType: "all",
  elementType: "labels.text.fill",
  stylers: [{
    saturation: 36
  }, {
    color: "#5f5f5f"
  }, {
    lightness: 40
  }]
}, {
  featureType: "all",
  elementType: "labels.text.stroke",
  stylers: [{
    visibility: "on"
  }, {
    color: "#ffffff"
  }, {
    lightness: 16
  }]
}, {
  featureType: "all",
  elementType: "labels.icon",
  stylers: [{
    visibility: "off"
  }]
}, {
  featureType: "administrative",
  elementType: "geometry.fill",
  stylers: [{
    color: "#fefefe"
  }, {
    lightness: 20
  }]
}, {
  featureType: "administrative",
  elementType: "geometry.stroke",
  stylers: [{
    color: "#fefefe"
  }, {
    lightness: 17
  }, {
    weight: 1.2
  }]
}, {
  featureType: "landscape.man_made",
  elementType: "geometry",
  stylers: [{
    saturation: 22
  }, {
    lightness: 54
  }, {
    gamma: 0.17
  }, {
    hue: "#005cff"
  }]
}, {
  featureType: "landscape.natural",
  elementType: "geometry",
  stylers: [{
    color: "#eef0f4"
  }]
}, {
  featureType: "poi",
  elementType: "geometry",
  stylers: [{
    color: "#eef0f4"
  }, {
    lightness: 21
  }]
}, {
  featureType: "poi.park",
  elementType: "geometry",
  stylers: [{
    color: "#e6e9f0"
  }, {
    lightness: 21
  }]
}, {
  featureType: "road.highway",
  elementType: "geometry.fill",
  stylers: [{
    color: "#ffffff"
  }, {
    lightness: 17
  }]
}, {
  featureType: "road.highway",
  elementType: "geometry.stroke",
  stylers: [{
    color: "#ffffff"
  }, {
    lightness: 29
  }, {
    weight: 0.2
  }]
}, {
  featureType: "road.arterial",
  elementType: "geometry",
  stylers: [{
    color: "#ffffff"
  }, {
    lightness: 18
  }]
}, {
  featureType: "road.local",
  elementType: "geometry",
  stylers: [{
    color: "#ffffff"
  }, {
    lightness: 16
  }]
}, {
  featureType: "transit",
  elementType: "geometry",
  stylers: [{
    color: "#eef0f4"
  }, {
    lightness: 19
  }]
}, {
  featureType: "water",
  elementType: "geometry",
  stylers: [{
    color: "#d7dae1"
  }, {
    lightness: 17
  }]
}];
exports.map = map;
var input = {
  inlineSpacing: 32,
  spacing: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.spacing,
  borderRadius: 3,
  background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.background,
  color: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.color,
  placeholderColor: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.placeholderColor,
  verticalPadding: 10,
  horizontalPadding: 10,
  "default": _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.border), {}, {
    background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.background,
    color: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.color,
    fontSize: "$small_regular",
    letterSpacing: "normal",
    lineHeight: 1.3,
    marginBottom: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.spacing
  }),
  disabled: _objectSpread({
    background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.disabledBackground
  }, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.disabledBorder),
  invalid: _objectSpread({
    background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.invalidBackground
  }, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.invalidBorder),
  small: {
    color: "$grayDarker",
    fontSize: "$small_small",
    letterSpacing: "normal",
    lineHeight: 1.4,
    height: 32
  },
  focus: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.focusBorder), {}, {
    background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.focusBackground
  }),
  radio: {
    size: 18,
    background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.white,
    borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.radioBorderRadius,
    border: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.border), {}, {
      borderColor: "$gray",
      borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.radioBorderRadius
    }),
    disabled: {
      background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.disabledBackground,
      border: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.disabledBorder), {}, {
        borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.radioBorderRadius
      })
    },
    invalid: {
      background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.invalidBackground,
      border: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.invalidBorder), {}, {
        borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.radioBorderRadius
      })
    },
    checkMark: {
      width: 8,
      height: 8,
      background: "$secondary",
      borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.radioBorderRadius
    }
  },
  checkbox: {
    size: 18,
    background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.white,
    borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.checkboxBorderRadius,
    border: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.border), {}, {
      borderColor: "$gray",
      borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.checkboxBorderRadius
    }),
    disabled: {
      background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.disabledBackground,
      border: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.disabledBorder), {}, {
        borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.checkboxBorderRadius
      })
    },
    invalid: {
      background: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.invalidBackground,
      border: _objectSpread(_objectSpread({}, _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.invalidBorder), {}, {
        borderRadius: _input.inputTokens === null || _input.inputTokens === void 0 ? void 0 : _input.inputTokens.checkboxBorderRadius
      })
    },
    checkMark: {
      width: 8,
      height: 8,
      background: "$secondary"
    }
  }
};
exports.input = input;
var container = {
  micro: 800,
  small: 1200,
  "default": 1440,
  large: 1800
};
exports.container = container;
var font = {
  family: {
    "default": 'Oxygen, -apple-system, BlinkMacSystemFont, Roboto, "Helvetica Neue", sans-serif',
    icon: "cinnecta-suite"
  },
  size: {
    small: {
      title1: 32,
      title2: 26,
      title3: 21,
      title4: 18,
      title5: 15,
      title6: 14,
      large: 17,
      regular: 15,
      small: 14,
      micro: 11
    },
    large: {
      title1: 34,
      title2: 29,
      title3: 23,
      title4: 20,
      title5: 16,
      title6: 14,
      large: 18,
      regular: 16,
      small: 14,
      micro: 11
    }
  }
};
exports.font = font;
var unit = 15;
exports.unit = unit;
var units = function units(value) {
  return value * unit;
};
exports.units = units;
var _createStitches = (0, _react.createStitches)({
    themeMap: _objectSpread(_objectSpread({}, _react.defaultThemeMap), {}, {
      height: "space",
      width: "space"
    }),
    media: {
      xlarge: "(min-width: ".concat(_breakpoints.breakpoints.xlarge - 1, "px)"),
      large: "(min-width: ".concat(_breakpoints.breakpoints.large - 1, "px)"),
      mediumAndAbove: "(min-width: ".concat(_breakpoints.breakpoints.medium, "px)"),
      medium: "(max-width: ".concat(_breakpoints.breakpoints.large - 1, "px)"),
      small: "(max-width: ".concat(_breakpoints.breakpoints.medium - 1, "px)")
    },
    utils: (_utils = {
      flexHorizontalCenter: function flexHorizontalCenter(gap) {
        return {
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
          gap: gap
        };
      },
      flexVerticalCenter: function flexVerticalCenter(gap) {
        return {
          display: "flex",
          flexDirection: "column",
          alignItems: "center",
          justifyContent: "center",
          gap: gap
        };
      },
      verticalPadding: function verticalPadding(value) {
        return {
          paddingTop: value,
          paddingBottom: value
        };
      },
      horizontalPadding: function horizontalPadding(value) {
        return {
          paddingRight: value,
          paddingLeft: value
        };
      },
      compactHorizontalPadding: function compactHorizontalPadding(value) {
        return {
          paddingRight: value,
          paddingLeft: value
        };
      }
    }, _defineProperty(_utils, "compactHorizontalPadding", function compactHorizontalPadding(value) {
      return {
        paddingRight: value,
        paddingLeft: value
      };
    }), _defineProperty(_utils, "cellColumnslarge", function cellColumnslarge(size) {
      return {
        "@large": {
          width: "".concat(100 / size, "%")
        }
      };
    }), _defineProperty(_utils, "size", function size(_size) {
      return {
        width: "".concat(_size / 12 * 100, "%")
      };
    }), _defineProperty(_utils, "mediumSize", function mediumSize(size) {
      return {
        "@mediumAndAbove": {
          width: "".concat(size / 12 * 100, "%")
        }
      };
    }), _defineProperty(_utils, "largeSize", function largeSize(size) {
      return {
        "@large": {
          width: "".concat(size / 12 * 100, "%")
        }
      };
    }), _defineProperty(_utils, "xlargeSize", function xlargeSize(size) {
      return {
        "@xlarge": {
          width: "".concat(size / 12 * 100, "%")
        }
      };
    }), _defineProperty(_utils, "columns", function columns(size) {
      return {
        width: "".concat(100 / size, "%")
      };
    }), _defineProperty(_utils, "columnsOnMedium", function columnsOnMedium(size) {
      return {
        "@mediumAndAbove": {
          width: "".concat(100 / size, "%")
        }
      };
    }), _defineProperty(_utils, "columnsOnLarge", function columnsOnLarge(size) {
      return {
        "@large": {
          width: "".concat(100 / size, "%")
        }
      };
    }), _defineProperty(_utils, "columnsOnXlarge", function columnsOnXlarge(size) {
      return {
        "@xlarge": {
          width: "".concat(100 / size, "%")
        }
      };
    }), _utils),
    theme: {
      colors: _colors.colors,
      fontSizes: _fontSizes.fontSizes,
      fontWeights: _fontWeights.fontWeights,
      lineHeight: _lineHeight.lineHeight,
      breakpoints: _breakpoints.breakpoints,
      space: _space.space
    }
  }),
  styled = _createStitches.styled,
  css = _createStitches.css,
  globalCss = _createStitches.globalCss,
  keyframes = _createStitches.keyframes,
  getCssText = _createStitches.getCssText,
  theme = _createStitches.theme,
  createTheme = _createStitches.createTheme,
  config = _createStitches.config,
  media = _createStitches.media,
  utils = _createStitches.utils;
exports.utils = utils;
exports.media = media;
exports.config = config;
exports.createTheme = createTheme;
exports.theme = theme;
exports.getCssText = getCssText;
exports.keyframes = keyframes;
exports.globalCss = globalCss;
exports.css = css;
exports.styled = styled;